################################################
Yukon Backend
################################################

* UAVCAN/Yukon python backend
* Uses new asynchronous pyuavcan to provide a REST interface over a libuavcan data bus
* Swagger Documentation provided

************************************************
Build Setup // Generated
************************************************

* Python 3.7 at least required

Start the demo UAVCAN node::

    python3 uavcan_node_demo.py

Run server::

    python3 api/main.py
